@@ -1,5 +1,5 @@
 package Schedule::LongSteps::Process;
-$Schedule::LongSteps::Process::VERSION = '0.015';
+$Schedule::LongSteps::Process::VERSION = '0.016';
 use Moose;
 use Log::Any qw/$log/;
 
@@ -118,5 +118,19 @@ sub wait_processes{
     return $self->new_step({ run_at => DateTime->now() });
 }
 
+
+=head2 revival_methods
+
+Returns an array-ref of revive methods associated with the process.
+
+=cut
+
+sub revival_methods {
+    my ($self) = @_;
+    my @revival_methods = map {$_->name}grep {$_->name =~ /^revive_/} $self->meta->get_all_methods;
+    return \@revival_methods;
+}
+
+
 __PACKAGE__->meta->make_immutable();
 
